@@ -298,6 +298,14 @@ def gcp_bucket_to_dataset(gcp_bucket_name, file_name, dataset_name, table_name):
         bucket = storage_client.bucket(gcp_bucket_name)
         blob = bucket.blob(file_name)
         blob.delete()
+        # Our downloader downloads by the paritiontime, however the default partitiontime is the date
+        # the data is uploaded to bigquery. Therefore, everything goes into one single day. The load
+        # job config does not let you upload to the _PARTITIONTIME because it is a prebuild column in
+        # bigquery. However, we do have permission to update it.
+        partition_date_sql = f"""
+        UPDATE `{table_id}` SET _PARTITIONTIME=CAST(DATE_TRUNC(DATE(usage_start_time), MONTH) AS timestamp) WHERE 1=1;
+        """
+        bigquery_client.query(partition_date_sql)
 
         LOG.info(f"Dataset {dataset_name} created in GCP bigquery under the table name {table_name}.")
     except GoogleCloudError as upload_err:
