@@ -14,40 +14,31 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
-"""Select regions.
+"""Select regions."""
 
-The tmp_REGIONS currently not used. Need to update
-https://github.com/project-koku/nise/blob/master/nise/generators/aws/aws_generator.py#L184
-in order to unlock the additional regions.
-
-"""
-
-REGIONS = ["us-east-1", "us-east-1", "us-west-1", "us-west-1", "us-west-2", "us-west-2"]
-
-tmp_REGIONS = [
-    "us-east-2",
+REGIONS = [
     "us-east-1",
     "us-west-1",
     "us-west-2",
-    "af-south-1",
+    "eu-north-1",
+    "eu-west-1",
+    "eu-central-1",
+    "eu-west-2",
+    "eu-west-3",
+    "eu-south-1",
+    "me-south-1",
     "ap-east-1",
-    "ap-south-1",
-    "ap-northeast-3",
-    "ap-northeast-2",
     "ap-southeast-1",
     "ap-southeast-2",
     "ap-northeast-1",
-    "ca-central-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
     "cn-north-1",
     "cn-northwest-1",
-    "eu-central-1",
-    "eu-west-1",
-    "eu-west-2",
-    "eu-south-1",
-    "eu-west-3",
-    "eu-north-1",
-    "me-south-1",
     "sa-east-1",
+    "ap-south-1",
+    "ca-central-1",
+    "af-south-1",
     "us-gov-east-1",
     "us-gov-west-1",
 ]
